@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-11-16 13:44:20
-@LastEditTime: 2021-11-29 16:40:24
+@LastEditTime: 2022-01-10 16:15:19
 @LastEditors: HuangJianYi
 :description: 报表模块
 """
@@ -32,8 +32,16 @@ class StatReportListHandler(ClientBaseHandler):
         start_date = self.get_param("start_date")
         end_date = self.get_param("end_date")
 
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "sort_index asc"
+        is_only_module = invoke_result_data.data["is_only_module"] if invoke_result_data.data.__contains__("is_only_module") else True
+
         stat_base_model = StatBaseModel(context=self)
-        stat_report_list = stat_base_model.get_stat_report_list(app_id, act_id, module_id, start_date, end_date)
+        stat_report_list = stat_base_model.get_stat_report_list(app_id, act_id, module_id, start_date, end_date, order_by, is_only_module)
         ref_params = {}
         stat_report_list = self.business_process_executed(stat_report_list, ref_params)
         return self.response_json_success(stat_report_list)
@@ -62,9 +70,16 @@ class TrendReportListHandler(ClientBaseHandler):
         start_date = self.get_param("start_date")
         end_date = self.get_param("end_date")
 
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "sort_index asc"
+        is_only_module = invoke_result_data.data["is_only_module"] if invoke_result_data.data.__contains__("is_only_module") else True
+
         stat_base_model = StatBaseModel(context=self)
-        trend_report_list = stat_base_model.get_trend_report_list(app_id, act_id, module_id, start_date, end_date)
+        trend_report_list = stat_base_model.get_trend_report_list(app_id, act_id, module_id, start_date, end_date, order_by, is_only_module)
         ref_params = {}
         trend_report_list = self.business_process_executed(trend_report_list, ref_params)
         return self.response_json_success(trend_report_list)
-
