@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-27 10:52:51
-@LastEditTime: 2021-12-02 17:58:45
+@LastEditTime: 2021-12-21 10:27:54
 @LastEditors: HuangJianYi
 @Description: 用户模块
 """
@@ -348,6 +348,7 @@ class AssetLogListHandler(ClientBaseHandler):
         :param open_id：open_id
         :param source_type：来源类型（1-购买2-任务3-手动配置4-抽奖5-回购）
         :param source_object_id：来源对象标识(比如来源类型是任务则对应任务类型)
+        :param operate_type：操作类型(0累计 1消耗)
         :return list
         :last_editors: HuangJianYi
         """
@@ -364,6 +365,7 @@ class AssetLogListHandler(ClientBaseHandler):
         source_object_id = self.get_param("source_object_id")
         asset_type = int(self.get_param("asset_type", 0))
         asset_object_id = self.get_param("asset_object_id")
+        operate_type = int(self.get_param("operate_type", -1))
 
         field = "*"
         invoke_result_data = self.business_process_executing()
@@ -372,7 +374,7 @@ class AssetLogListHandler(ClientBaseHandler):
         else:
             field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
         asset_base_model = AssetBaseModel(context=self)
-        page_info = asset_base_model.get_asset_log_list(app_id, act_id, asset_type, page_size, page_index, user_id, asset_object_id, start_date, end_date, user_nick, user_open_id, source_type, source_object_id, field, is_cache=False)
+        page_info = asset_base_model.get_asset_log_list(app_id, act_id, asset_type, page_size, page_index, user_id, asset_object_id, start_date, end_date, user_nick, user_open_id, source_type, source_object_id, field, is_cache=False, operate_type=operate_type)
         ref_params = {}
         page_info.data = self.business_process_executed(page_info.data, ref_params)
         return self.response_json_success(page_info)
