@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-03-06 23:17:54
-@LastEditTime: 2021-11-17 17:53:59
+@LastEditTime: 2022-01-06 19:06:31
 @LastEditors: HuangJianYi
 :Description: 数据库基础操作类
 """
@@ -56,7 +56,7 @@ class CacheModel(BaseModel):
                 params_str += "_" + str(params)
         cache_key = str(field + "_" + where + "_" + group_by + "_" + order_by + "_" + limit + params_str).replace(" ", "").lower()
         return CryptoHelper.md5_encrypt(cache_key)
-        
+
     def __get_dependency_cache_key(self, dependency_key, cache_key):
         """
         :Description: 获取依赖缓存key
@@ -103,7 +103,7 @@ class CacheModel(BaseModel):
         else:
             cache_data = json.loads(cache_data)
             return cache_data
-                             
+
     def __set_dependency_cache(self, dependency_key, cache_key,value, cache_expire):
         """
         :Description: 获取依赖缓存值
@@ -170,14 +170,14 @@ class CacheModel(BaseModel):
         if limit:
             limit = " LIMIT "+str(limit)
         sql = f"SELECT {field} FROM {self.table_name}{where}{group_by}{order_by}{limit};"
-        
+
         dependency_key = self.__get_dependency_key(str(dependency_key))
         cache_key = "entitylist_" + self.table_name + "_" + self.__get_cache_key('*',where,group_by,order_by,limit,params)
         list_row = self.__get_dependency_cache(dependency_key,cache_key)
         if list_row and config.get_value("is_redis_cache",True) == True:
             if list_row == 'null':
-                return None    
-            return self._BaseModel__row_entity_list(list_row) 
+                return None
+            return self._BaseModel__row_entity_list(list_row)
         else:
             list_row = self.db.fetch_all_rows(sql, params)
             cache_value = deepcopy(list_row)
@@ -211,7 +211,7 @@ class CacheModel(BaseModel):
 
         sql = f"SELECT {field} FROM {self.table_name}{where}{group_by}{order_by} LIMIT {limit};"
         count_sql = f"SELECT COUNT({self.primary_key_field}) AS count FROM {self.table_name}{where}{group_by};"
-        
+
         dependency_key = self.__get_dependency_key(str(dependency_key))
         cache_key = "entitypagelist_" + self.table_name + "_" + self.__get_cache_key(field,where,group_by,order_by,limit,params)
         page_list = self.__get_dependency_cache(dependency_key,cache_key)
@@ -229,7 +229,7 @@ class CacheModel(BaseModel):
             page_list["row_count"] = row_count
             self.__set_dependency_cache(dependency_key,cache_key,page_list,cache_expire)
             return self._BaseModel__row_entity_list(page_list["data"]), row_count
-            
+
     def get_cache_entity(self, where='', group_by='', order_by='',  params=None, dependency_key='', cache_expire=600):
         """
         :Description: 根据条件获取实体对象
@@ -255,7 +255,7 @@ class CacheModel(BaseModel):
         one_row = self.__get_dependency_cache(dependency_key,cache_key)
         if one_row and config.get_value("is_redis_cache",True) == True:
             if one_row == 'null':
-                return None    
+                return None
             return self._BaseModel__row_entity(one_row)
         else:
             one_row = self.db.fetch_one_row(sql, params)
@@ -274,13 +274,13 @@ class CacheModel(BaseModel):
         where = f"{self.primary_key_field}=%s"
         params = [primary_key_id]
         sql = f"SELECT * FROM {self.table_name} WHERE {where};"
- 
+
         dependency_key = self.__get_dependency_key(str(dependency_key))
         cache_key = "entityone_" + self.table_name + "_" + self.__get_cache_key('*',where,'','','',params)
         one_row = self.__get_dependency_cache(dependency_key,cache_key)
         if one_row and config.get_value("is_redis_cache",True) == True:
             if one_row == 'null':
-                return None 
+                return None
             return self._BaseModel__row_entity(one_row)
         else:
             one_row = self.db.fetch_one_row(sql,params)
@@ -351,14 +351,17 @@ class CacheModel(BaseModel):
         dependency_key = self.__get_dependency_key(str(dependency_key))
         cache_key = "dict_" + self.table_name + "_" + self.__get_cache_key(field,where,group_by,order_by,limit,params)
         one_row = self.__get_dependency_cache(dependency_key,cache_key)
-        
+
         if one_row and config.get_value("is_redis_cache",True) == True:
             if one_row == 'null':
-                return None    
+                return None
             return one_row
         else:
             one_row = self.db.fetch_one_row(sql, params)
             self.__set_dependency_cache(dependency_key,cache_key,one_row,cache_expire)
+            if one_row:
+                for field in one_row:
+                    one_row[field] = self._BaseModel__convert_field_type(one_row[field])
             return one_row
 
     def get_cache_dict_by_id(self, primary_key_id, dependency_key='', cache_expire=600, field="*"):
@@ -380,11 +383,14 @@ class CacheModel(BaseModel):
         one_row = self.__get_dependency_cache(dependency_key,cache_key)
         if one_row and config.get_value("is_redis_cache",True) == True:
             if one_row == 'null':
-                return None    
+                return None
             return one_row
         else:
             one_row = self.db.fetch_one_row(sql,params)
             self.__set_dependency_cache(dependency_key,cache_key,one_row,cache_expire)
+            if one_row:
+                for field in one_row:
+                    one_row[field] = self._BaseModel__convert_field_type(one_row[field])
             return one_row
 
     def get_cache_dict_list(self, where='', group_by='', order_by='', limit='', field="*", params=None, dependency_key='',cache_expire=600):
@@ -419,6 +425,10 @@ class CacheModel(BaseModel):
         else:
             list = self.db.fetch_all_rows(sql, params)
             self.__set_dependency_cache(dependency_key,cache_key,list,cache_expire)
+            if list and len(list) > 0:
+                for one_row in list:
+                    for field in one_row:
+                        one_row[field] = self._BaseModel__convert_field_type(one_row[field])
             return list
 
     def get_cache_dict_page_list(self, field="*", page_index=0 ,page_size=20, where='', group_by='' ,order_by='' ,params=None, dependency_key='', cache_expire=600):
@@ -445,7 +455,7 @@ class CacheModel(BaseModel):
         limit = f"{str(int(page_index) * int(page_size))},{str(page_size)}"
         sql = f"SELECT {field} FROM {self.table_name}{where}{group_by}{order_by} LIMIT {limit}"
         count_sql = f"SELECT COUNT({self.primary_key_field}) AS count FROM {self.table_name}{where}{group_by};"
-   
+
         dependency_key = self.__get_dependency_key(str(dependency_key))
         cache_key = "dictpagelist_" + self.table_name + "_" + self.__get_cache_key(field,where,group_by,order_by,limit,params)
         page_list = self.__get_dependency_cache(dependency_key,cache_key)
@@ -462,4 +472,8 @@ class CacheModel(BaseModel):
             page_list["data"] = list_row
             page_list["row_count"] = row_count
             self.__set_dependency_cache(dependency_key,cache_key,page_list,cache_expire)
+            if list_row and len(list_row) > 0:
+                for one_row in list_row:
+                    for field in one_row:
+                        one_row[field] = self._BaseModel__convert_field_type(one_row[field])
             return list_row, row_count
