@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-11-24 09:36:39
-@LastEditTime: 2021-12-15 17:11:00
+@LastEditTime: 2022-01-04 15:32:53
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -35,11 +35,12 @@ class ErpConsoleModel():
             j = threading.Thread(target=self.process_order_pull, args=[i, mod_count])
             j.start()
 
-    def process_order_push(self, mod_value, mod_count):
+    def process_order_push(self, mod_value, mod_count, is_loop = True):
         """
         :description: 处理订单推送到遁甲系统
         :param mod_value: 当前队列值
         :param mod_count: 队列数
+        :param is_loop: 是否循环
         :return: 
         :last_editors: HuangJianYi
         """
@@ -89,8 +90,11 @@ class ErpConsoleModel():
                         except Exception as ex:
                             logger_error.error(f"推送订单队列{mod_value}异常,json串:{SevenHelper.json_dumps(erp_relation_dict)},ex:{traceback.format_exc()}")
                             continue
-                else:
+                
+                if is_loop == True and len(erp_relation_list) <= 0:
                     time.sleep(60)
+                if is_loop == False:
+                    break
             except Exception as ex:
                 time.sleep(5)
 
