@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-27 10:55:09
-@LastEditTime: 2021-11-24 13:37:38
+@LastEditTime: 2021-12-01 17:34:14
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -54,6 +54,7 @@ class PrizeOrder:
         self.create_date = "1900-01-01 00:00:00"  # 创建时间
         self.create_month = 0  # 创建月
         self.create_day = 0  # 创建天
+        self.modify_date = "1900-01-01 00:00:00"  # 修改时间
         self.sync_status = 0  # 订单同步状态，用于遁甲或者ERP同步订单（0未同步，1同步成功，2同步失败）
         self.sync_date = "1900-01-01 00:00:00"  # 同步时间
         self.sync_count = 0  # 同步次数
@@ -73,7 +74,7 @@ class PrizeOrder:
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'order_no', 'app_id', 'act_id', 'module_id', 'user_id', 'open_id', 'user_nick', 'real_name', 'telephone', 'province', 'city', 'county', 'street', 'address', 'deliver_date', 'express_no', 'express_company', 'order_status', 'buyer_remark', 'seller_remark', 'order_price', 'is_free_freight', 'freight_price', 'freight_pay_order_no', 'create_date', 'create_month', 'create_day', 'sync_status', 'sync_date', 'sync_count', 'sync_result', 'i1', 'i2', 'i3', 'i4', 'i5', 's1','s2', 's3', 's4', 's5', 'd1', 'd2']
+        return ['id', 'order_no', 'app_id', 'act_id', 'module_id', 'user_id', 'open_id', 'user_nick', 'real_name', 'telephone', 'province', 'city', 'county', 'street', 'address', 'deliver_date', 'express_no', 'express_company', 'order_status', 'buyer_remark', 'seller_remark', 'order_price', 'is_free_freight', 'freight_price', 'freight_pay_order_no', 'create_date', 'create_month', 'create_day', 'modify_date', 'sync_status', 'sync_date', 'sync_count', 'sync_result', 'i1', 'i2', 'i3', 'i4', 'i5', 's1','s2', 's3', 's4', 's5', 'd1', 'd2']
 
     @classmethod
     def get_primary_key(self):
