@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 09:24:43
-@LastEditTime: 2021-12-30 11:51:21
+@LastEditTime: 2022-01-06 17:57:11
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -30,7 +30,7 @@ class OrderBaseModel(FrameBaseModel):
         self.context = context
         super(OrderBaseModel,self).__init__(context)
 
-    def _delete_prize_order_dependency_key(self,act_id):
+    def _delete_prize_order_dependency_key(self, act_id, user_id):
         """
         :description: 删除订单依赖建
         :param act_id: 活动标识
@@ -38,9 +38,27 @@ class OrderBaseModel(FrameBaseModel):
         :last_editors: HuangJianYi
         """
         try:
+            dependency_key = f"prize_order_list:actid_{act_id}"
+            if user_id:
+                dependency_key += f"_userid_{user_id}"
             redis_init = SevenHelper.redis_init()
-            if act_id:
-                redis_init.delete(f"prize_order_list:actid_{act_id}")
+            redis_init.delete(dependency_key)
+        except Exception as ex:
+            pass
+
+    def _delete_prize_roster_dependency_key(self, act_id, user_id):
+        """
+        :description: 删除中奖记录依赖建
+        :param act_id: 活动标识
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        try:
+            dependency_key = f"prize_roster_list:actid_{act_id}"
+            if user_id:
+                dependency_key += f"_userid_{user_id}"
+            redis_init = SevenHelper.redis_init()
+            redis_init.delete(dependency_key)
         except Exception as ex:
             pass
 
@@ -479,7 +497,8 @@ class OrderBaseModel(FrameBaseModel):
             return invoke_result_data
 
         SevenHelper.redis_release_lock(acquire_lock_name, identifier)
-        self._delete_prize_order_dependency_key(act_id)
+        self._delete_prize_order_dependency_key(act_id,user_id)
+        self._delete_prize_roster_dependency_key(act_id, user_id)
         invoke_result_data.data = prize_order.__dict__
         return invoke_result_data
 
