@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 09:39:08
-@LastEditTime: 2021-12-06 15:30:17
+@LastEditTime: 2022-01-10 16:14:47
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -79,7 +79,7 @@ class StatBaseModel(FrameBaseModel):
             stat_queue.create_date = SevenHelper.get_now_datetime()
             stat_queue.process_date = SevenHelper.get_now_datetime()
             stat_queue_list.append(stat_queue)
-        
+
         stat_process_ways = config.get_value("stat_process_ways","mysql")
         if stat_process_ways == "mysql":
             sub_table = SevenHelper.get_sub_table(act_id,config.get_value("stat_sub_table_count",0))
@@ -90,7 +90,7 @@ class StatBaseModel(FrameBaseModel):
             for stat_queue in stat_queue_list:
                 redis_init.rpush(f"stat_queue_list:{str(user_id % 10)}", SevenHelper.json_dumps(stat_queue))
 
-    def get_stat_report_list(self,app_id,act_id,module_id,start_date,end_date,order_by="sort_index asc"):
+    def get_stat_report_list(self, app_id, act_id, module_id, start_date, end_date, order_by="sort_index asc", is_only_module=False):
         """
         :description: 报表数据列表(表格)
         :param app_id：应用标识
@@ -99,6 +99,7 @@ class StatBaseModel(FrameBaseModel):
         :param start_date：开始时间
         :param end_date：结束时间
         :param order_by：排序
+        :param is_only_module：是否只取module的数据
         :return list
         :last_editors: HuangJianYi
         """
@@ -110,8 +111,10 @@ class StatBaseModel(FrameBaseModel):
         if end_date != "":
             condition += " and create_date<%s"
             params.append(end_date)
-
-        stat_orm_list = StatOrmModel(context=self.context).get_list("((act_id=%s and module_id=%s) or (act_id=0 and module_id=0)) and is_show=1", order_by=order_by, params=[act_id,module_id])
+        if is_only_module == True:
+            stat_orm_list = StatOrmModel(context=self.context).get_list("act_id=%s and module_id=%s and is_show=1", order_by=order_by, params=[act_id, module_id])
+        else:
+            stat_orm_list = StatOrmModel(context=self.context).get_list("((act_id=%s and module_id=%s) or (act_id=0 and module_id=0)) and is_show=1", order_by=order_by, params=[act_id,module_id])
         if len(stat_orm_list)<=0:
             return []
         key_name_s = ','.join(["'%s'" % str(stat_orm.key_name) for stat_orm in stat_orm_list])
@@ -182,8 +185,8 @@ class StatBaseModel(FrameBaseModel):
             common_group_data_list.append(group_data)
 
         return common_group_data_list
-    
-    def get_trend_report_list(self,app_id,act_id,module_id,start_date,end_date,order_by="sort_index asc"):
+
+    def get_trend_report_list(self, app_id, act_id, module_id, start_date, end_date, order_by="sort_index asc", is_only_module=False):
         """
         :description: 报表数据列表(趋势图)
         :param app_id：应用标识
@@ -192,6 +195,7 @@ class StatBaseModel(FrameBaseModel):
         :param start_date：开始时间
         :param end_date：结束时间
         :param order_by：排序
+        :param is_only_module：是否只取module的数据
         :return list
         :last_editors: HuangJianYi
         """
@@ -203,8 +207,10 @@ class StatBaseModel(FrameBaseModel):
         if end_date != "":
             condition += " and create_date<%s"
             params.append(end_date)
-
-        stat_orm_list = StatOrmModel(context=self.context).get_list("((act_id=%s and module_id=%s) or (act_id=0 and module_id=0)) and is_show=1", order_by=order_by, params=[act_id,module_id])
+        if is_only_module == True:
+            stat_orm_list = StatOrmModel(context=self.context).get_list("act_id=%s and module_id=%s and is_show=1", order_by=order_by, params=[act_id, module_id])
+        else:
+            stat_orm_list = StatOrmModel(context=self.context).get_list("((act_id=%s and module_id=%s) or (act_id=0 and module_id=0)) and is_show=1", order_by=order_by, params=[act_id,module_id])
         if len(stat_orm_list)<=0:
             return []
         key_name_s = ','.join(["'%s'" % str(stat_orm.key_name) for stat_orm in stat_orm_list])
@@ -287,7 +293,7 @@ class StatBaseModel(FrameBaseModel):
 
         return common_group_data_list
 
-    def process_invite_report(self,app_id,act_id,module_id,user_id,login_token,invite_user_id,handler_name,check_user_nick=True,continue_request_expire=5):
+    def process_invite_report(self,app_id,act_id,module_id,user_id,login_token,invite_user_id,handler_name,check_user_nick=True,continue_request_expire=5,is_stat=True):
         """
         :description: 处理邀请进入上报
         :param app_id:应用标识
@@ -299,6 +305,7 @@ class StatBaseModel(FrameBaseModel):
         :param handler_name:接口名称
         :param check_user_nick:是否校验昵称为空
         :param continue_request_expire:连续请求过期时间，为0不进行校验，单位秒
+        :param is_stat:是否统计上报
         :return 
         :last_editors: HuangJianYi
         """
@@ -310,33 +317,33 @@ class StatBaseModel(FrameBaseModel):
             if user_id == invite_user_id:
                 invoke_result_data.success = False
                 invoke_result_data.error_code = "error"
-                invoke_result_data.error_message = "无效邀请" 
+                invoke_result_data.error_message = "无效邀请"
                 return invoke_result_data
-            
+
             invoke_result_data = self.business_process_executing(app_id,act_id,module_id,user_id,login_token,handler_name,False,check_user_nick,continue_request_expire,acquire_lock_name)
             if invoke_result_data.success == True:
                 act_info_dict = invoke_result_data.data["act_info_dict"]
                 act_module_dict = invoke_result_data.data["act_module_dict"]
                 user_info_dict = invoke_result_data.data["user_info_dict"]
                 identifier = invoke_result_data.data["identifier"]
+                if is_stat == True:
+                    stat_base_model = StatBaseModel(context=self.context)
+                    key_list_dict = {}
+                    key_list_dict["AddBeInvitedUserCount"] = 1 #从分享进入新增用户数
+                    key_list_dict["BeInvitedUserCount"] = 1 #从分享进入用户数
+                    key_list_dict["BeInvitedCount"] = 1 #从分享进入次数
+                    stat_base_model.add_stat_list(app_id, act_id, module_id, user_info_dict["user_id"], user_info_dict["open_id"], key_list_dict)
 
-                stat_base_model = StatBaseModel(context=self.context)
-                key_list_dict = {}
-                key_list_dict["AddBeInvitedUserCount"] = 1 #从分享进入新增用户数
-                key_list_dict["BeInvitedUserCount"] = 1 #从分享进入用户数
-                key_list_dict["BeInvitedCount"] = 1 #从分享进入次数
-                stat_base_model.add_stat_list(app_id, act_id, module_id, user_info_dict["user_id"], user_info_dict["open_id"], key_list_dict)
-            
         except Exception as ex:
             self.context.logging_link_error("【处理邀请上报】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "exception"
-            invoke_result_data.error_message = "系统繁忙,请稍后再试"    
-        
+            invoke_result_data.error_message = "系统繁忙,请稍后再试"
+
         self.business_process_executed(act_id,module_id,user_id,handler_name,acquire_lock_name,identifier)
 
-        return invoke_result_data 
-        
+        return invoke_result_data
+
     def process_share_report(self,app_id,act_id,module_id,user_id,login_token,handler_name,check_user_nick=True,continue_request_expire=5,is_stat=True):
         """
         :description: 处理分享上报
@@ -371,8 +378,8 @@ class StatBaseModel(FrameBaseModel):
             self.context.logging_link_error("【处理分享上报】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "exception"
-            invoke_result_data.error_message = "系统繁忙,请稍后再试"    
-        
+            invoke_result_data.error_message = "系统繁忙,请稍后再试"
+
         self.business_process_executed(act_id,module_id,user_id,handler_name,acquire_lock_name,identifier)
 
         return invoke_result_data
\ No newline at end of file
