@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2021-12-29 09:40:59
+@LastEditTime: 2022-01-05 15:05:51
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -795,6 +795,9 @@ class UserBaseModel(FrameBaseModel):
             return invoke_result_data
 
         user_address_model = UserAddressModel()
+        if is_default == 1:
+            user_address_model.update_table("is_default=0", "act_id=%s and user_id=%s", params=[act_id, user_id])
+
         if user_address_id > 0:
             user_address = user_address_model.get_entity("id=%s", params=[user_address_id])
             if not user_address:
@@ -809,7 +812,8 @@ class UserBaseModel(FrameBaseModel):
             user_address.county = county
             user_address.street = street
             user_address.address = address
-            user_address_model.update_entity(user_address, "real_name,telephone,province,city,county,street,address")
+            user_address.is_default = is_default
+            user_address_model.update_entity(user_address, "real_name,telephone,province,city,county,street,address,is_default")
         else:
             user_address = UserAddress()
             user_address.app_id = app_id
